===========
AlgoTik TSE
===========

.. image:: https://img.shields.io/pypi/v/algotik_tse.svg
        :target: https://pypi.python.org/pypi/algotik_tse

.. image:: https://img.shields.io/pypi/pyversions/algotik_tse.svg
        :target: https://pypi.python.org/pypi/algotik_tse

.. image:: https://img.shields.io/pypi/l/algotik_tse.svg
        :target: https://github.com/mohsenalipour/algotik_tse/blob/main/LICENSE


A comprehensive Python library for fetching Tehran Stock Exchange (TSETMC)
and currency/coin market data.


* Free software: GNU General Public License v3
* Website: https://algotik.com
* Documentation: https://github.com/mohsenalipour/algotik_tse#readme
* Telegram: https://t.me/algotik


Features
--------

* Stock price history with Jalali date support
* Options, ETFs, Bonds, and Fund data
* Real/Legal (retail/institutional) client type data
* Intraday trading details, order book, and market watch
* Shareholders data and capital increase history
* Currency and coin prices (TGJU)
* Full-text search across all TSETMC symbols
* Configurable settings (timeout, retries, rate limiting)


Credits
-------

Developed and maintained by `Mohsen Alipour <https://algotik.com>`_ (alipour@algotik.ir).
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
